@@ -13,13 +13,16 @@ DATABASES = {
     }
 SITE_ID = 1
 INSTALLED_APPS = [
+    'lizard_map.testmodelapp',
+    # ^^^ Only for testing! Django-nose problem.
+    # See https://github.com/jbalogh/django-nose/issues/15
     'lizard_map',
     'lizard_ui',
     'staticfiles',
     'compressor',
-    'django_nose',
     'piston',
     'south',
+    'django_nose',
     'debug_toolbar',
     'django_extensions',
     'django.contrib.gis',
@@ -31,7 +34,7 @@ INSTALLED_APPS = [
     ]
 ROOT_URLCONF = 'lizard_map.urls'
 
-#TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
+TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
 
 # Used for django-staticfiles
 STATIC_URL = '/static_media/'
