@@ -6,9 +6,6 @@ from django.contrib import admin
 from lizard_ui.urls import debugmode_urlpatterns
 
 import lizard_map.views
-import lizard_map.configchecker
-
-lizard_map.configchecker  # Pyflakes...
 admin.autodiscover()
 
 urlpatterns = patterns(
@@ -85,7 +82,7 @@ urlpatterns = patterns(
         name="lizard_map.search_coordinates"),  # L3
     url(r'^search_name/',
         'lizard_map.views.search_coordinates',
-        {'format': 'name'},
+        {'_format': 'name'},
         name="lizard_map.search_name"),  # L3
 
     # Workspace storage
