@@ -18,6 +18,7 @@ from django.views.generic.base import TemplateView
 from django.views.generic.base import View
 import Image
 import csv
+import iso8601
 import logging
 import mapnik
 import urllib2
@@ -73,7 +74,7 @@ class GoogleTrackingMixin(object):
     """
     Google tracking code.
     """
-    def google_tracking_code():
+    def google_tracking_code(self):
         try:
             return settings.GOOGLE_TRACKING_CODE
         except AttributeError:
@@ -815,8 +816,10 @@ def popup_collage_json(collage_items, popup_id, request=None):
         collage_item = collage_items[0]  # Each group always has items.
         identifiers = [collage_item.identifier for
                        collage_item in collage_items]
+
         html.append(
-            collage_item.html(identifiers=identifiers, is_collage=True))
+            collage_item.html(identifiers=identifiers, is_collage=True,
+                              request=request))
 
     result = {'id': popup_id,
               'html': html,
@@ -991,7 +994,7 @@ def search(workspace, google_x, google_y, radius):
 
 
 # L3
-def search_coordinates(request, workspace_storage_id=None, format='popup'):
+def search_coordinates(request, workspace_storage_id=None, _format='popup'):
     """searches for objects near GET x,y,radius returns json_popup of
     results.
 
@@ -1009,6 +1012,7 @@ def search_coordinates(request, workspace_storage_id=None, format='popup'):
     # xy params from the GET request.
     x = float(request.GET.get('x'))
     y = float(request.GET.get('y'))
+    format = request.GET.get('format', _format)
     # TODO: convert radius to correct scale (works now for google + rd)
     radius = float(request.GET.get('radius'))
     radius_search = radius
@@ -1025,7 +1029,11 @@ def search_coordinates(request, workspace_storage_id=None, format='popup'):
         workspace = WorkspaceStorage.objects.get(pk=workspace_storage_id)
     else:
         user_workspace_id = request.GET.get('user_workspace_id', None)
-        workspace = WorkspaceEdit.objects.get(pk=user_workspace_id)
+        if user_workspace_id is not None:
+            workspace = WorkspaceEdit.objects.get(pk=user_workspace_id)
+        else:
+            stored_workspace_id = request.GET.get('stored_workspace_id', None)
+            workspace = WorkspaceStorage.objects.get(pk=stored_workspace_id)
 
     found = search(workspace, google_x, google_y, radius)
 
@@ -1045,11 +1053,20 @@ def search_coordinates(request, workspace_storage_id=None, format='popup'):
             result['x'] = x + (radius / 10)
             result['y'] = y - (radius / 10)
             return HttpResponse(json.dumps(result))
+        elif format == 'object':
+            result = [{'id':f['identifier'], 'name':f['name']}
+            for f in found]
+
+            return HttpResponse(json.dumps(result))
+
         else:
             # default: as popup
             return popup_json(found, request=request)
     else:
-        return popup_json([], request=request)
+        if format == 'object':
+            return HttpResponse([])
+        else:
+            return popup_json([], request=request)
 
 
 class CollageDetailView(
@@ -1391,7 +1408,6 @@ def create_mapnik_image(request, data):
         for name in styles:
             mapnik_map.append_style(name, styles[name])
 
-
     #Zoom and create image
     logger.debug("Zooming to box...")
     mapnik_map.zoom_to_box(mapnik.Envelope(*data['bbox']))
@@ -1412,13 +1428,16 @@ def mapnik_image_to_stream(request, data, img):
     logger.debug("Converting image to rgba...")
 
     bbox = ",".join([str(x) for x in data['bbox']])
-    geoserver_img = urllib2.urlopen("http://10.100.130.132:8080/geoserver/"+
-        "wms?LAYERS=nhi%3Awaterkaart&FORMAT=image%2Fpng&MAXRESOLUTION=364&SERVICE"+
-        "=WMS&VERSION=1.1.1&REQUEST=GetMap&STYLES=&EXCEPTIONS=application%2Fvnd."+
-        "ogc.se_inimage&SRS=EPSG%3A28992&BBOX="+ str(bbox) +
-        "&WIDTH="+ str(data['width']) +"&HEIGHT=" + str(data['height'])).read()
-
-    # ^^^ TODO: This should be configurable! (Added by gnijholt on Sep 28 2011)
+    geoserver_img = urllib2.urlopen(
+        "http://10.100.130.132:8080/geoserver/" +
+        "wms?LAYERS=waterkaart&FORMAT=image%2Fpng&MAXRESOLUTION=364&SERVICE" +
+        "=WMS&VERSION=1.1.1&REQUEST=GetMap&STYLES=" +
+        "&EXCEPTIONS=application%2Fvnd." +
+        "ogc.se_inimage&SRS=EPSG%3A28992&BBOX=" + str(bbox) +
+        "&WIDTH=" + str(data['width']) +
+        "&HEIGHT=" + str(data['height'])).read()
+    # ^^^ TODO: This should be configurable! (Added by gnijholt on Sep
+    # 28 2011)
     base_image = Image.open(StringIO.StringIO(geoserver_img))
     rgba_image = Image.fromstring('RGBA',
                                   (data['width'], data['height']),
@@ -1427,7 +1446,7 @@ def mapnik_image_to_stream(request, data, img):
     base_w, base_h = base_image.size
     rgba_w, rgba_h = rgba_image.size
 
-    offset = ((base_w-rgba_w), (base_h-rgba_h))
+    offset = ((base_w - rgba_w), (base_h - rgba_h))
     base_image.paste(rgba_image, offset, rgba_image)
     # ^^^ Passing rgba_image twice to get transparency working in paste()
 
@@ -1486,6 +1505,11 @@ def statistics_csv(request):
 class AdapterMixin(object):
     """
     Provide functions to get adapter stuff from get request
+
+    Supported URL GET parameters: adapter_layer_json, identifier
+    (multiple allowed), dt_start, dt_end.
+
+    TODO: tests
     """
     def adapter(self, adapter_class):
         """
@@ -1506,39 +1530,86 @@ class AdapterMixin(object):
         identifier = parse_identifier_json(identifier_json)
         return identifier
 
+    def start_end_dates_from_request(self):
+        """
+        Try to get dt_start, dt_end from url parameters, revert to
+        "current_start_end_dates".
+
+        dt_start and dt_end are in iso8601 format
+        """
+        current_start_date, current_end_date = current_start_end_dates(
+                self.request)
+
+        start_date_str = self.request.GET.get('dt_start', None)
+        if start_date_str is None:
+            start_date = current_start_date
+        else:
+            start_date = iso8601.parse_date(start_date_str)
+
+        end_date_str = self.request.GET.get('dt_end', None)
+        if end_date_str is None:
+            end_date = current_end_date
+        else:
+            end_date = iso8601.parse_date(end_date_str)
+
+        return start_date, end_date
+
+    def layout_extra_from_request(self):
+        """Check for url parameter layout_extra (in json) and return parsed.
+        """
+        result = {}
+        layout_extra_json = self.request.GET.get('layout_extra', None)
+        if layout_extra_json is not None:
+            result = json.loads(layout_extra_json)
+        return result
+
 
 class ImageMixin(object):
+    """
+    Provide functions for a View that return an image.
+
+    Supported URL GET parameters: width, height.
+
+    TODO: tests
+    """
     def width_height(self):
-        width = self.request.GET.get('width')
-        height = self.request.GET.get('height')
+        width = self.request.GET.get('width', None)
+        height = self.request.GET.get('height', None)
 
-        if width:
+        if width is not None:
             width = int(width)
-        else:
-            # We want None, not u''.
-            width = None
 
-        if height:
+        if height is not None:
             height = int(height)
-        else:
-            # We want None, not u''.
-            height = None
+
         return width, height
 
 
 class AdapterImageView(AdapterMixin, ImageMixin, View):
+    """
+    Return result of adapter.image, using given parameters.
+
+    URL GET parameters:
+    - adapter_class (required)
+    - identifier (required, multiple supported)
+    - width, height (optional)
+    - start_date, end_date (optional, iso8601 format, default current)
+    - layout_extra (optional)
+    """
+
     def get(self, request, *args, **kwargs):
         """
-        named url arguments become kwargs
+        Note: named url arguments become kwargs.
         """
         current_adapter = self.adapter(kwargs['adapter_class'])
         identifier_list = self.identifiers()
         width, height = self.width_height()
 
-        start_date, end_date = current_start_end_dates(self.request)
+        start_date, end_date = self.start_end_dates_from_request()
 
-        # add animation slider position
-        layout_extra = slider_layout_extra(self.request)
+        # Add animation slider position, info from session data.
+        layout_extra = self.layout_extra_from_request()
+        layout_extra.update(slider_layout_extra(self.request))
 
         return current_adapter.image(
             identifier_list, start_date, end_date,
@@ -1548,26 +1619,29 @@ class AdapterImageView(AdapterMixin, ImageMixin, View):
 
 class AdapterValuesView(AdapterMixin, ViewContextMixin, TemplateView):
     """
-    Values for a single identifier
+    Return values for a single identifier in csv or html.
+
+    URL GET parameters:
+    - adapter_class (required)
+    - identifier (required, single)
+    - output_type (optional, choices are 'csv' or 'html'. Default 'html')
+    - start_date, end_date (optional, iso8601 format, default current)
 
-    Format in csv, html
     """
     template_name = 'lizard_map/box_table.html'
 
     def get(self, request, *args, **kwargs):
         adapter = self.adapter(kwargs['adapter_class'])
-        output_type = self.kwargs['output_type']
+        output_type = self.kwargs.get('output_type', None)
         identifier = self.identifier()
-        self.start_date, self.end_date = current_start_end_dates(self.request)
+        start_date, end_date = self.start_end_dates_from_request()
 
-        self.values = adapter.values(
-            identifier, self.start_date, self.end_date)
+        self.values = adapter.values(identifier, start_date, end_date)
 
         self.name = adapter.location(**identifier).get('name', 'export')
 
         if output_type == 'csv':
-            filename = '%s.csv' % (
-                self.name)
+            filename = '%s.csv' % (self.name)
             # Make the csv output.
             response = HttpResponse(mimetype='text/csv')
             response['Content-Disposition'] = (
@@ -1580,4 +1654,5 @@ class AdapterValuesView(AdapterMixin, ViewContextMixin, TemplateView):
             return response
         else:
             # Make html table using self.values
-            return super(AdapterValuesView, self).get(request, *args, **kwargs)
+            return super(AdapterValuesView, self).get(
+                request, *args, **kwargs)
