@@ -68,6 +68,19 @@ class WorkspaceItemAdapter(object):
         """
         raise NotImplementedError
 
+    @classmethod
+    def identifiers(self):
+        """
+        New in L3. Retrieve a list of all possible identifiers.
+
+        This function is optional. It is used with REST APIs.
+
+        Identifiers are dictionaries with for each adapter its custom
+        keys and values. The meaning is only useful within a single
+        adapter.
+        """
+        raise NotImplementedError
+
     # def extent(self, identifiers=None):
     #     """
     #     Returns extent {'west':.., 'north':.., 'east':.., 'south':..}
@@ -378,7 +391,7 @@ class WorkspaceItemAdapter(object):
             # Fallback if no legend found (should not happen)
             logger.warn("Could not find legend for key '%s', "
                         "please configure the legend. "
-                        "Now using fallback (red)." % legend_name)
+                        "Now using fallback (red).", legend_name)
             color = Color('ff0000')
             found_legend = Legend(descriptor="", min_color=color,
                                   max_color=color, too_low_color=color,
